# ogstools 0.0.3 Release Notes

This is the first release of the `ogstools`-package, a joint effort of OGS users and developers to strengthen the OGS ecosystem!

## Tools

### msh2vtu

The `msh2vtu`-tool by Dominik Kern (TU Bergakademie Freiberg) has been integrated into ogstools. For more info see [](../user-guide/msh2vtu.md). Its former repository at GitHub [dominik-kern/msh2vtu](https://github.com/dominik-kern/msh2vtu) has been deprecated and development continues under the ogstools umbrella.

## Infrastructure

### Documentation web site

This documentation website has been implemented and is available at <https://ogs.ogs.xyz/tools/ogstools>.

### Unit testing and style checks

A [tox](https://tox.wiki)-based test driver for unit tests and style checks has been implemented. See [](../development/index.md#testing-with-tox-and-pytest) for more info.
